summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicolas Goaziou <mail@nicolasgoaziou.fr>2015-12-29 22:44:00 +0100
committerNicolas Goaziou <mail@nicolasgoaziou.fr>2015-12-29 22:45:14 +0100
commit7a4803d3ac6903dfa97ec3652b4a77143298e2fe (patch)
tree470a67fdb8c26ae6718484600a8454557ca0e4c4
parentbc0588fee4994eda9474e62313eb9925ad65dab1 (diff)
downloadorg-mode-7a4803d3ac6903dfa97ec3652b4a77143298e2fe.tar.gz
Fix failing test
* testing/lisp/test-org-datetree.el (test-org-datetree/find-iso-week-create): Fix failing test.
-rw-r--r--testing/lisp/test-org-datetree.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/testing/lisp/test-org-datetree.el b/testing/lisp/test-org-datetree.el
index dab54ba..721ec2d 100644
--- a/testing/lisp/test-org-datetree.el
+++ b/testing/lisp/test-org-datetree.el
@@ -172,8 +172,8 @@
(let ((org-datetree-add-timestamp 'inactive))
(org-datetree-find-iso-week-create '(12 31 2014)))
(org-trim (buffer-string)))))
;; Insert at top level, unless some node has DATE_WEEK_TREE
;; property. In this case, date tree becomes one of its sub-trees.
(should
(string-match
"\\* 2015"
@@ -183,9 +183,9 @@
(org-trim (buffer-string)))))
(should
(string-match
- "\\*\\* H1.1\n:PROPERTIES:\n:DATE_WEEK_TREE: t\n:END:\n\\*\\*\\* 2015"
+ "\\*\\* H1.1\n:PROPERTIES:\n:WEEK_TREE: t\n:END:\n\\*\\*\\* 2015"
(org-test-with-temp-text
- "* H1\n** H1.1\n:PROPERTIES:\n:DATE_WEEK_TREE: t\n:END:\n* H2"
+ "* H1\n** H1.1\n:PROPERTIES:\n:WEEK_TREE: t\n:END:\n* H2"
(let ((org-datetree-add-timestamp nil))
(org-datetree-find-iso-week-create '(12 31 2014)))
(org-trim (buffer-string)))))
@@ -172,8 +172,8 @@
(org-datetree-find-iso-week-create '(12 31 2014)))
(org-trim (buffer-string)))))
- ;; Insert at top level, unless some node has DATE_WEEK_TREE
- ;; property. In this case, date tree becomes one of its sub-trees.
+ ;; Insert at top level, unless some node has WEEK_TREE property. In
+ ;; this case, date tree becomes one of its sub-trees.
(should
(string-match